@@ -52,27 +52,27 @@ class Accountant:
             book_balance.append(dict(balance))
         return book_balance
 
-    def get_book_balances(self, currency: str):
+    def get_book_balances(self, currency: str, metadata_filter: dict = {}):
         log.info("---------Balance----------")
         blocked_deposit_balance = self.ledger.get_book_balances(
             book_id=self.bank_account['ledger_books']['blocked_balance']['id'],
-            asset_id=currency, metadata_filter={'operation': 'DEPOSIT'})
+            asset_id=currency, metadata_filter={**{'operation': 'DEPOSIT'}, **metadata_filter})
         blocked_withdraw_balance = self.ledger.get_book_balances(
             book_id=self.bank_account['ledger_books']['blocked_balance']['id'],
-            asset_id=currency, metadata_filter={'operation': 'WITHDRAW'})
+            asset_id=currency, metadata_filter={**{'operation': 'WITHDRAW'}, **metadata_filter})
         main_balance = self.ledger.get_book_balances(book_id=self.bank_account['ledger_books']['main_balance']['id'],
-                                                     asset_id=currency)
+                                                     asset_id=currency, metadata_filter={**metadata_filter})
         return {'currency': currency,
                 'blocked_balance_deposit': float(blocked_deposit_balance.get(currency, 0)),
                 'blocked_balance_withdraw': float(blocked_withdraw_balance.get(currency, 0)),
                 'main_balance': float(main_balance.get(currency, 0))}
 
-    def withdraw_block_amount(self, value: str, currency: str, memo: str):
+    def withdraw_block_amount(self, value: str, currency: str, memo: str, metadata: dict = {}):
         log.info("---------Block_Amount_Withdraw----------")
         operation = self.ledger.post_transfer_sync(
             from_book_id=self.bank_account['ledger_books']['main_balance']['id'],
             to_book_id=self.bank_account['ledger_books']['blocked_balance']['id'], asset_id=currency, value=value,
-            memo=memo, metadata={'operation': 'WITHDRAW'})
+            memo=memo, metadata={**{"operation": "WITHDRAW"}, **metadata})
         log.info(operation)
         return operation
 
